## ========  Package Documentation  ============ 
#' naijR: Operations to Ease Data Analyses Specific to Nigeria
#' 
#' The naijR package is essentially an R package about Nigeria and for Nigeria.
#' 
#' @details naijR contains a number of functions that facilitate the
#' management of data sets of interest including data cleaning and wrangling,
#' as well as making available a number of facilities for geospatial data
#' visualisation.
#' 
#' @author Victor Ordu
#' @aliases naijR-package
#' @keywords internal
"_PACKAGE"



## ========  Lifecycle badge  ================== 
## usethis namespace: start
#' @importFrom lifecycle deprecate_soft
## usethis namespace: end
NULL
